@@ -3,8 +3,8 @@
 # Contact: doomy [at] dokuleser [dot] org
 # Copyright 2008 Winfried Neessen
 #
-# $Id: API.pm 18 2010-12-05 13:34:25Z doomy $
-# Last modified: [ 2010-12-05 14:32:21 ]
+# $Id: API.pm,v 1.6 2008-10-14 21:05:29 doomy Exp $
+# Last modified: [ 2008-10-14 23:04:34 ]
 
 ### Module definitions {{{
 package Ipernity::API;
@@ -17,7 +17,7 @@ use LWP::UserAgent;
 use XML::Simple;
 
 our @ISA = qw(LWP::UserAgent);
-our $VERSION = '0.08';
+our $VERSION = '0.05';
 # }}}
 
 ### Module constructor / new() {{{
@@ -28,9 +28,9 @@ sub new
 	my $self = new LWP::UserAgent;
 
 	### Read arguments and assign them to my object
-	my $args = shift;
-	foreach my $key (keys %{$args}) {
-		$self->{args}->{$key} = $args->{$key};
+	my %args = @_;
+	foreach my $key (keys %args) {
+		$self->{$key} = $args{$key};
 	}
 	
 	### For Ipernity we need an output format
@@ -67,19 +67,12 @@ sub execute
 }
 # }}}
 
-### Execute the API request and return a XML object / execute_hash() {{{
-sub execute_hash()
+### Execute the API request and return a XML object / execute_xml() {{{
+sub execute_xml()
 {
 	### Get object and request
 	my $self = shift;
 	my %args = @_;
-	my $oldformat;
-
-	### For XML output we need to force XML outputformat
-	if(lc($self->{args}->{outputformat}) ne 'xml') {
-		$oldformat = $self->{args}->{outputformat};
-		$self->{args}->{outputformat} = 'xml';
-	}
 
 	### Execute the request
 	my $response = $self->execute(%args)->{_content};
@@ -88,30 +81,17 @@ sub execute_hash()
 	my $xml = new XML::Simple;
 	my $xmlresult = $xml->XMLin(
 		$response, 
-		ForceContent => 1,
-		ForceArray   => 1,
+		ForceContent => 1
 	);
 
 	### Check the status of the request
 	CheckResponse($xmlresult);
 
-	## Restore old outputformat
-	if(defined($oldformat)) {
-		$self->{args}->{outputformat} = $oldformat;
-	}
-
-	### Return the hash
+	### Return the xmlhash
 	return $xmlresult;
 }
 # }}}
 
-### Information placeholder for execute_xml / execute_xml() {{{
-sub execute_xml()
-{
-	return "execute_xml() has been renamed to execute_hash()";
-}
-# }}}
-
 ### Execute the API request / execute_request() {{{
 sub execute_request
 {
@@ -128,7 +108,7 @@ sub execute_request
 
 	### Encode the arguments and build a POST request
 	$request->encode();
-	
+
 	### Call the API
 	my $response = $self->request($request);
 
@@ -169,12 +149,12 @@ sub fetchfrob
 	my $frob = {};
 
 	### Create an API request
-	my $response = $self->execute_hash(
+	my $response = $self->execute_xml(
 		'method' => 'auth.getFrob',
 	);
 
 	### Return the frob
-	return $response->{auth}->[0]->{frob}->[0]->{content};
+	return $response->{auth}->{frob}->{content};
 }
 # }}}
 
@@ -238,19 +218,19 @@ sub authtoken
 	my $frob = shift;
 
 	### Create an API request
-	my $response = $self->execute_hash(
+	my $response = $self->execute_xml(
 		'method' => 'auth.getToken',
 		'frob'	 => $frob,
 	);
 
 	### Let's safe the auth token and user information
-	$self->{auth}->{authtoken} = $response->{auth}->[0]->{token}->[0]->{content};
-	$self->{auth}->{realname}  = $response->{auth}->[0]->{user}->[0]->{realname};
-	$self->{auth}->{userid}    = $response->{auth}->[0]->{user}->[0]->{user_id};
-	$self->{auth}->{username}  = $response->{auth}->[0]->{user}->[0]->{username};
+	$self->{auth}->{authtoken} = $response->{auth}->{token}->{content};
+	$self->{auth}->{realname}  = $response->{auth}->{user}->{realname};
+	$self->{auth}->{userid}    = $response->{auth}->{user}->{user_id};
+	$self->{auth}->{username}  = $response->{auth}->{user}->{username};
 
 	### Return the AuthToken
-	return $response->{auth}->[0]->{token}->[0]->{content};
+	return $response->{auth}->{token}->{content};
 }
 # }}}
 
@@ -265,7 +245,7 @@ sub CheckResponse
 	my $status = $xmlhash->{'status'};
 
 	### We caught an error - let's die!
-	if(lc($status) ne 'ok') {
+	if(lc($status) eq 'error') {
 		$code = $xmlhash->{code};
 		$msg  = $xmlhash->{message};
 		croak("An API call caught an unexpected error: " . $msg . " (Error Code: " . $code . ")");
@@ -278,101 +258,64 @@ sub CheckResponse
 
 1;
 __END__
-
 =head1 NAME
 
 Ipernity::API - Perl interface to the Ipernity API
 
 =head1 SYNOPSIS
 
-	use Ipernity::API;
-	
-	my $api = Ipernity::API->new({
-		'api_key'	=> '12345678901234567890123456789012',
-		'secret'	=> '0123456789012345',
-		'outputformat'	=> 'xml',
-	});
+use Ipernity::API
 
-	my $raw_response = $api->execute(
-		'method'	=> 'test.hello',
-	);
+=head1 USAGE
 
-	my $hash = $api->execute_hash(
-		'method'	=> 'test.hello',
-		'auth_token'	=> '12345-123-1234567890',
-	);
-	
-	my $frob = $api->fetchfrob();
+use Ipernity::API;
 
-	my $authurl = $api->authurl(
-		'frob'		=> $frob,
-		'perms'		=> {
-			'perm_doc'	=> 'read',
-			'perm_network'	=> 'write',
-			'perm_blog'	=> 'delete',
-		},
-	};
+my $api = Ipernity::API->new(
+   'args'   => {
+      'api_key'      => '12345678901234567890123456789012',
+      'secret'       => '0123456789012345',
+      'outputformat' => 'xml',
+   }
+);
 
-	my $token = $api->authtoken( $frob );
+my $raw_response = $api->execute(
+   'method'	=> 'test.hello',
+);
 
-	### After fetching the authtoken, all useful user information are
-	### stored in the $api->{auth} section for later usage
+my $hashref = $api->execute_xml(
+   'method'	=> 'test.hello',
+   'auth_token'	=> '12345-123-1234567890',
+);
 
-	my $username  = $api->{auth}->{username};
-	my $user_id   = $api->{auth}->{userid};
-	my $realname  = $api->{auth}->{realname};
-	my $authtoken = $api->{auth}->{authtoken};
+my $frob = $api->fetchfrob();
 
-=head1 DESCRIPTION
+my $authurl = $api->authurl(
+   'frob'	=> $frob,
+   'perms' => {
+       'perm_doc'	=> 'read',
+       'perm_network'	=> 'write',
+       'perm_blog'	=> 'delete',
+   },
+);
 
-Ipernity::API is a full implementation of the Ipernity API interface. It uses
-LWP::UserAgent to communicate with the API and returns the results in the 3
-possible formats (provided by Ipernity): JSON, XML, SOAP, XML-RPC
+my $token = $api->authtoken($frob);
 
-=head1 METHODS
+### After fetching the authtoken, all useful user information are
+### stored in the $api->{auth} section for later usage
 
-=over 4
+my $username  = $api->{auth}->{username};
 
-=item B<new>( configuration hash )
+my $user_id   = $api->{auth}->{userid};
 
-The constructor takes a hashref with all needed configuration values as argument.
-B<api_key> and B<secret> are mandatory values. The B<outputformat> is option and
-will be set to XML if not defined.
+my $realname  = $api->{auth}->{realname};
 
-=item B<fetchfrob>()
-
-This method fetches a frob from Ipernity, which later can be used to generate and
-authentication URL and an AuthToken
-
-=item B<authurl>( config hash )
-
-Generates an authentication URL which can be provided to the user. This is needed
-so that the user can confirm that he grants permissions to the script. This method
-requires a B<frob> and a B<perms> parameter to be set.
-
-=item B<authtoken>( frob )
-
-Will fetch the AuthToken from Ipernity for later usage (for authenticated API calls).
-This method requires a valid frob to be provided as argument.
-
-=item B<execute>( ipernity parameters )
-
-Calling this method will execute the provided method together with its options on
-the Ipernity API. As result the method returns the raw answer from the API so that
-the script can take care of parsing the output from Ipernity on its own
-
-=item B<execute_hash>( ipernity parameters )
-
-Works similar to B<execute>() but returns a hashref for easy access to the results
-from Ipernity
+my $authtoken = $api->{auth}->{authtoken};
 
 =back
 
-=head1 CAVEATS
+=head1 DESCRIPTION
 
-Since version 0.07 the execute_hash() function always returns arrays, even
-if the XML result would be only one. Please not that you might have to adjust
-your code, in case you are upgradeing to v0.07 (which is highly recommended)
+To be done.
 
 =head1 AUTHOR
 
@@ -380,37 +323,26 @@ Winfried Neessen, E<lt>doomy@dokuleser.org<gt>
 
 =head1 REQUIRES
 
-Perl 5, URI, HTTP::Request, XML::Simple, LWP::UserAgent, Digest::MD5
+Perl 5, URI, HTTP::Request, XML::Twig, LWP::UserAgent, Digest::MD5
 
-=head1 BUGS
+=head1 COPYRIGHT and LICENCE
 
-Please report bugs in the CPAN bug tracker.
-
-=head1 COPYRIGHT
-
-Copyright (c) 2008-2010, Winfried Neessen <doomy@dokuleser.org>
-All rights reserved.
+Copyright (c) 2008, Winfried Neessen <doomy@dokuleser.org>
 
 Redistribution and use in source and binary forms, with or without
-modification, are permitted provided that the following conditions are met:
-    * Redistributions of source code must retain the above copyright
-      notice, this list of conditions and the following disclaimer.
-    * Redistributions in binary form must reproduce the above copyright
-      notice, this list of conditions and the following disclaimer in the
-      documentation and/or other materials provided with the distribution.
-    * Neither the name of the neessen.net nor the
-      names of its contributors may be used to endorse or promote products
-      derived from this software without specific prior written permission.
+modification, is not permitted.
 
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
-DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
+ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
-LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
+ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
+$Id: API.pm,v 1.6 2008-10-14 21:05:29 doomy Exp $
+
 =cut
